@@ -5,6 +5,7 @@ pub(crate) type UnresolvedRecipe<'src> = Recipe<'src, UnresolvedDependency<'src>
 impl<'src> UnresolvedRecipe<'src> {
   pub(crate) fn resolve(
     self,
+    module_path: &str,
     resolved: Vec<Arc<Recipe<'src>>>,
   ) -> CompileResult<'src, Recipe<'src>> {
     assert_eq!(
@@ -37,11 +38,19 @@ impl<'src> UnresolvedRecipe<'src> {
       .into_iter()
       .zip(resolved)
       .map(|(unresolved, resolved)| Dependency {
+        arguments: resolved.group_arguments(&unresolved.arguments),
         recipe: resolved,
-        arguments: unresolved.arguments,
       })
       .collect();
 
+    let mut namepath = String::from(module_path);
+
+    if !namepath.is_empty() {
+      namepath.push_str("::");
+    }
+
+    namepath.push_str(self.name.lexeme());
+
     Ok(Recipe {
       attributes: self.attributes,
       body: self.body,
@@ -50,7 +59,7 @@ impl<'src> UnresolvedRecipe<'src> {
       file_depth: self.file_depth,
       import_offsets: self.import_offsets,
       name: self.name,
-      namepath: self.namepath,
+      namepath: Some(namepath),
       parameters: self.parameters,
       priors: self.priors,
       private: self.private,
