@@ -37,7 +37,12 @@ fn flag() {
   assert_stdout(&output, stdout);
 }
 
-const JUSTFILE_CMD: &str = r#"
+/// Test that we can use `set shell` to use cmd.exe on windows
+#[test]
+#[cfg(windows)]
+fn cmd() {
+  let tmp = temptree! {
+    justfile: r#"
 
 set shell := ["cmd.exe", "/C"]
 
@@ -46,14 +51,7 @@ x := `Echo`
 recipe:
   REM foo
   Echo "{{x}}"
-"#;
-
-/// Test that we can use `set shell` to use cmd.exe on windows
-#[test]
-#[cfg_attr(unix, ignore)]
-fn cmd() {
-  let tmp = temptree! {
-    justfile: JUSTFILE_CMD,
+"#,
   };
 
   let output = Command::new(executable_path("just"))
@@ -66,7 +64,12 @@ fn cmd() {
   assert_stdout(&output, stdout);
 }
 
-const JUSTFILE_POWERSHELL: &str = r#"
+/// Test that we can use `set shell` to use cmd.exe on windows
+#[test]
+#[cfg(windows)]
+fn powershell() {
+  let tmp = temptree! {
+      justfile: r#"
 
 set shell := ["powershell.exe", "-c"]
 
@@ -75,15 +78,9 @@ x := `Write-Host "Hello, world!"`
 recipe:
   For ($i=0; $i -le 10; $i++) { Write-Host $i }
   Write-Host "{{x}}"
-"#;
-
-/// Test that we can use `set shell` to use cmd.exe on windows
-#[test]
-#[cfg_attr(unix, ignore)]
-fn powershell() {
-  let tmp = temptree! {
-    justfile: JUSTFILE_POWERSHELL,
-  };
+"#
+  ,
+    };
 
   let output = Command::new(executable_path("just"))
     .current_dir(tmp.path())
@@ -95,49 +92,66 @@ fn powershell() {
   assert_stdout(&output, stdout);
 }
 
-test! {
-  name: shell_args,
-  justfile: "
+#[test]
+fn shell_args() {
+  Test::new()
+    .arg("--shell-arg")
+    .arg("-c")
+    .justfile(
+      "
     default:
       echo A${foo}A
   ",
-  args: ("--shell-arg", "-c"),
-  stdout: "AA\n",
-  stderr: "echo A${foo}A\n",
-  shell: false,
+    )
+    .shell(false)
+    .stdout("AA\n")
+    .stderr("echo A${foo}A\n")
+    .run();
 }
 
-test! {
-  name: shell_override,
-  justfile: "
+#[test]
+fn shell_override() {
+  Test::new()
+    .arg("--shell")
+    .arg("bash")
+    .justfile(
+      "
     set shell := ['foo-bar-baz']
 
     default:
       echo hello
   ",
-  args: ("--shell", "bash"),
-  stdout: "hello\n",
-  stderr: "echo hello\n",
-  shell: false,
+    )
+    .shell(false)
+    .stdout("hello\n")
+    .stderr("echo hello\n")
+    .run();
 }
 
-test! {
-  name: shell_arg_override,
-  justfile: "
+#[test]
+fn shell_arg_override() {
+  Test::new()
+    .arg("--shell-arg")
+    .arg("-cu")
+    .justfile(
+      "
     set shell := ['foo-bar-baz']
 
     default:
       echo hello
   ",
-  args: ("--shell-arg", "-cu"),
-  stdout: "hello\n",
-  stderr: "echo hello\n",
-  shell: false,
+    )
+    .stdout("hello\n")
+    .stderr("echo hello\n")
+    .shell(false)
+    .run();
 }
 
-test! {
-  name: set_shell,
-  justfile: "
+#[test]
+fn set_shell() {
+  Test::new()
+    .justfile(
+      "
     set shell := ['echo', '-n']
 
     x := `bar`
@@ -146,10 +160,11 @@ test! {
       echo {{x}}
       echo foo
   ",
-  args: (),
-  stdout: "echo barecho foo",
-  stderr: "echo bar\necho foo\n",
-  shell: false,
+    )
+    .stdout("echo barecho foo")
+    .stderr("echo bar\necho foo\n")
+    .shell(false)
+    .run();
 }
 
 #[test]
